##  Getting Started with AI Agent Discovery
  1. Activate the AI agent extension to the meta model. This extension adds the needed entities to your workspace. Before activating the extension, review the changes that will apply to your workspace. For details, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
  2. Configure integrations for discovering AI agents and MCP servers, or upload AI agents through the API. For detailed instructions, see:
     * [Uploading AI Agents Through the API](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api?locale=en-US&state=PRODUCTION&version=CLOUD "Upload AI agent cards to SAP LeanIX using the AI Agent API. Preview uploaded AI agents in the AI discovery inbox and add relevant fact sheets to your workspace.")
     * [Discovering AI Agents from Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to integrate SAP LeanIX with Microsoft Entra ID to automate the discovery of AI agents.")
     * [Discovering AI Agents from Google Agent Engine](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to integrate SAP LeanIX with Google Agent Engine to automate the discovery of AI agents.")
     * [Discovering SAP AI Agents](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to integrate SAP LeanIX with SAP Cloud ALM to automate the discovery of SAP AI agents.")
     * [Discovering MCP Servers from Microsoft Azure API Center](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center?locale=en-US&state=PRODUCTION&version=CLOUD "Discover your MCP servers registered in Microsoft Azure API Center. Review discovered items and add them to your inventory in SAP LeanIX.")
     * [Discovering AI Agents from Amazon Bedrock](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock?locale=en-US&state=PRODUCTION&version=CLOUD "Integrate SAP LeanIX with Amazon Bedrock Agents and Amazon Bedrock AgentCore to automatically discover your AI agents.")
  3. Review discovered items in the AI agent discovery inbox. Decide which AI agents and MCP servers you want to add to your inventory or ignore. When applicable, link discovered items to suggested fact sheets. To learn more, see [AI Agent Discovery Inbox](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD "AI agents and MCP servers discovered across your enterprise landscape appear in the AI agent discovery inbox. Learn how to review, link, and reject fact sheets related to discovered items.").


YesNo
Send
Help us provide a better digital experience for you and all other visitors.
What is the purpose of your visit to our website today?
  * Understand software features and benefits for a possible purchase
  * Find information about how to use the software
  * Find implementation or configuration information
  * Find information on installing or upgrading the software
  * Find information to troubleshoot and resolve issues that I'm encountering
  * Find developer or API information
  * Learn about new or updated product features
  * Other (please specify)


You can write a maximum of 255 characters.
Were you able to complete your task?
  * Yes
  * No


Why were you not able to complete your task today?
You can write a maximum of 4000 characters.
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
